@@ -1,4 +1,4 @@
-from greble_flow.processors.base import BaseFlowProcessor
+from grebble_flow.processors.base import BaseFlowProcessor
 
 
 class SimpleProcessor(BaseFlowProcessor):
